/**-----------------------------------------------------------------------------------------
* Copyright © 2024 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { ColumnCellTemplateDirective } from './column-cell-template.directive';
import { ColumnHeaderTemplateDirective } from './column-header-template.directive';
import * as i0 from "@angular/core";
/**
 * Represents the column definition of the [MultiColumnComboBox]({% slug overview_multicolumncombobox %})
 * ([see example]({% slug columns_multicolumncombobox %})).
 */
export declare class ComboBoxColumnComponent {
    /**
     * @hidden
     */
    cellTemplate: ColumnCellTemplateDirective;
    /**
     * @hidden
     */
    headerTemplate: ColumnHeaderTemplateDirective;
    /**
     * The field to which the column is bound.
     *
     * > The `field` property can be set to point to a nested property value - e.g. `category.name`.
     */
    field: string;
    /**
     * The title of the column.
     */
    title: string;
    /**
     * The width of the column (in pixels).
     */
    width: number;
    /**
     * Sets the visibility of the column.
     *
     * @default false
     */
    hidden: boolean;
    /**
     * Sets the custom styles for the table cells (excluding the header ones) of the column.
     * Under the hood, to apply the property, the style option uses the NgStyle directive.
     */
    style: {
        [key: string]: string;
    };
    /**
     * Sets the custom styles for the header cell of the column.
     * Under the hood, to apply the property, the headerStyle option uses the NgStyle directive.
     */
    headerStyle: {
        [key: string]: string;
    };
    /**
     * Sets the custom CSS classes to the column cells.
     * Under the hood, to apply the property, the class option uses the NgClass directive.
     */
    class: string | string[] | Set<string> | {
        [key: string]: any;
    };
    /**
     * Sets the custom CSS classes to the column header cell.
     * Under the hood, to apply the property, the headerClass option uses the NgClass directive.
     */
    headerClass: string | string[] | Set<string> | {
        [key: string]: any;
    };
    /**
     * Sets the condition that needs to be satisfied for a column to remain visible.
     * If you set the [`hidden`]({% slug api_dropdowns_comboboxcolumncomponent %}#toc-hidden) property, the behavior of `media` is overridden.
     */
    media: string;
    /**
     * @hidden
     */
    matchesMedia: boolean;
    static ɵfac: i0.ɵɵFactoryDeclaration<ComboBoxColumnComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<ComboBoxColumnComponent, "kendo-combobox-column", never, { "field": "field"; "title": "title"; "width": "width"; "hidden": "hidden"; "style": "style"; "headerStyle": "headerStyle"; "class": "class"; "headerClass": "headerClass"; "media": "media"; }, {}, ["cellTemplate", "headerTemplate"], never, true, never>;
}
