/**-----------------------------------------------------------------------------------------
* Copyright © 2024 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { EventEmitter, QueryList, ElementRef, SimpleChange, ChangeDetectorRef, NgZone, Renderer2 } from '@angular/core';
import { AfterViewInit, OnChanges, OnDestroy } from '@angular/core';
import { ListItemDirective } from './list-item.directive';
import { ItemTemplateDirective } from './templates/item-template.directive';
import { GroupTemplateDirective } from './templates/group-template.directive';
import { FixedGroupTemplateDirective } from './templates/fixed-group-template.directive';
import { SelectionService } from './selection/selection.service';
import { DisabledItemsService } from './disabled-items/disabled-items.service';
import { DataService } from './data.service';
import { VirtualizationSettings } from './models/virtualization-settings';
import { PageChangeEvent } from './models/page-change-event';
import { MultiSelectCheckableSettings } from './models/checkboxes-settings';
import { DropDownSize } from './models/size';
import { DropDownRounded } from './models/rounded';
import { ListType } from './models/list-type';
import { NavigationAction } from './navigation/navigation-action';
import * as i0 from "@angular/core";
/**
 * @hidden
 */
export declare class ListComponent implements OnChanges, OnDestroy, AfterViewInit {
    dataService: DataService;
    wrapper: ElementRef<HTMLElement>;
    private selectionService;
    private disabledItemsService;
    private cdr;
    private zone;
    private renderer;
    selected: any[];
    focused: number;
    textField: string;
    valueField: string;
    height: number;
    template: ItemTemplateDirective;
    groupTemplate: GroupTemplateDirective;
    fixedGroupTemplate: FixedGroupTemplateDirective;
    show: boolean;
    id: string;
    optionPrefix: string;
    multipleSelection: boolean;
    virtual: VirtualizationSettings;
    type: ListType;
    checkboxes: MultiSelectCheckableSettings;
    ariaLive: string;
    isMultiselect: boolean;
    isActionSheetExpanded: boolean;
    showStickyHeader: boolean;
    set data(data: any[]);
    get data(): any[];
    set size(size: DropDownSize);
    get size(): DropDownSize;
    rounded: DropDownRounded;
    onClick: EventEmitter<any>;
    pageChange: EventEmitter<PageChangeEvent>;
    listResize: EventEmitter<boolean>;
    popupListScroll: EventEmitter<any>;
    items: QueryList<ListItemDirective>;
    content: ElementRef<HTMLElement>;
    list: ElementRef<HTMLElement>;
    virtualContainer: ElementRef<HTMLElement>;
    currentGroup: string;
    startFrom: number;
    lastLoaded: number;
    lastScrollTop: number;
    listContentClass: string;
    listClass: string;
    listItemClass: string;
    listVirtualClass: string;
    listGroupStickyHeaderClass: string;
    listGroupStickyHeaderTextClass: string;
    listGroupItemClass: string;
    listGroupItemTextClass: string;
    private scrollToFocused;
    private _data;
    private scrollSubscription;
    private selectSubscription;
    private _size;
    get pageSize(): number;
    get scrollHeight(): number;
    get overflowY(): string;
    /**
     * @hidden
     */
    get checkboxClasses(): any;
    constructor(dataService: DataService, wrapper: ElementRef<HTMLElement>, selectionService: SelectionService, disabledItemsService: DisabledItemsService, cdr: ChangeDetectorRef, zone: NgZone, renderer: Renderer2);
    ngOnChanges(changes: {
        [propertyName: string]: SimpleChange;
    }): void;
    ngAfterViewInit(): void;
    private setGroupAttributes;
    ngAfterViewChecked(): void;
    ngOnDestroy(): void;
    onCheckedChange(e: Event, index: number): void;
    prepareClasses(): void;
    isChecked(index: number): boolean;
    firstVisibleItem(): any;
    findCurrentGroup(): void;
    prefetchData(): void;
    changePage(start: number): void;
    index(groupIndex: number, itemIndex: number): number;
    getText(dataItem: any): any;
    getValue(dataItem: any): any;
    isDisabled(index: number): boolean;
    isAltRow(index: number): boolean;
    scrollToItem(index: number): void;
    scrollWithOnePage(action: NavigationAction): void;
    scrollToIndex(index: number): void;
    scroll(item: ElementRef<HTMLElement>): void;
    /**
     * Indicates whether a scrollbar is currently rendered in the list.
     */
    hasScrollbar(): boolean;
    isItemSelected(index: number): boolean;
    /**
     * Sets the list's content overflow (hides/shows scrollbar)
     */
    private setOverflow;
    /**
     * Indicates whether the scrollbar should be visible in virtual mode.
     */
    private hasVirtualScrollbar;
    private positionItems;
    /**
     * Indicates whether the first group header from the data set is in the targeted virtual page.
     */
    private firstGroupHeaderInTargetedPage;
    private setComponentClasses;
    static ɵfac: i0.ɵɵFactoryDeclaration<ListComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<ListComponent, "kendo-list", never, { "selected": "selected"; "focused": "focused"; "textField": "textField"; "valueField": "valueField"; "height": "height"; "template": "template"; "groupTemplate": "groupTemplate"; "fixedGroupTemplate": "fixedGroupTemplate"; "show": "show"; "id": "id"; "optionPrefix": "optionPrefix"; "multipleSelection": "multipleSelection"; "virtual": "virtual"; "type": "type"; "checkboxes": "checkboxes"; "ariaLive": "ariaLive"; "isMultiselect": "isMultiselect"; "isActionSheetExpanded": "isActionSheetExpanded"; "showStickyHeader": "showStickyHeader"; "data": "data"; "size": "size"; "rounded": "rounded"; }, { "onClick": "onClick"; "pageChange": "pageChange"; "listResize": "listResize"; "popupListScroll": "popupListScroll"; }, never, never, true, never>;
}
