/**-----------------------------------------------------------------------------------------
* Copyright © 2024 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { EventEmitter, Renderer2, ElementRef } from '@angular/core';
import { TagTemplateDirective } from '../common/templates/tag-template.directive';
import { GroupTagTemplateDirective } from '../common/templates/group-tag-template.directive';
import { DropDownSize } from './models/size';
import { DropDownRounded } from './models/rounded';
import { DropDownFillMode } from './models/fillmode';
import { SVGIcon } from '@progress/kendo-svg-icons';
import * as i0 from "@angular/core";
/**
 * @hidden
 */
export declare class TagListComponent {
    private renderer;
    hostElement: ElementRef<HTMLElement>;
    /**
     * @hidden
     */
    xCircleIcon: SVGIcon;
    tags: any[];
    textField: string | string[];
    valueField: string | string[];
    valueDepth: number[];
    focused: number;
    template: TagTemplateDirective;
    groupTemplate: GroupTagTemplateDirective;
    disabled: boolean;
    tagPrefix: string;
    id: string;
    set size(size: DropDownSize);
    get size(): DropDownSize;
    rounded: DropDownRounded;
    fillMode: DropDownFillMode;
    /**
     * A collection with the disabled tags' indices.
     */
    disabledIndices: Set<number>;
    removeTag: EventEmitter<any>;
    hostClasses: boolean;
    get hostId(): string;
    taglistRole: string;
    multiselectable: boolean;
    private _size;
    constructor(renderer: Renderer2, hostElement: ElementRef<HTMLElement>);
    tagProp(tag: any, prop: string | string[], index: number): string;
    isTagDisabled(tag: any, positionIndex: number): boolean;
    deleteTag(event: any, tag: any, index: number): void;
    itemId(tag: any, index: any): string;
    isGroupTag(tag: any): boolean;
    tagAriaHidden(index: any): boolean;
    private getPropField;
    static ɵfac: i0.ɵɵFactoryDeclaration<TagListComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<TagListComponent, "kendo-taglist", never, { "tags": "tags"; "textField": "textField"; "valueField": "valueField"; "valueDepth": "valueDepth"; "focused": "focused"; "template": "template"; "groupTemplate": "groupTemplate"; "disabled": "disabled"; "tagPrefix": "tagPrefix"; "id": "id"; "size": "size"; "rounded": "rounded"; "fillMode": "fillMode"; "disabledIndices": "disabledIndices"; }, { "removeTag": "removeTag"; }, never, ["*"], true, never>;
}
